<?php declare(strict_types=1);

namespace MyPrayerJournal;

use Exception;
use Visus\Cuid2\Cuid2;

/**
 * A prayer request
 */
class Request
{
    /**
     * @param string $id The ID for the request
     * @param string $enteredOn The date/time this request was originally entered
     * @param string $userId The ID of the user to whom this request belongs
     * @param string|null $snoozedUntil The date/time the snooze expires for this request (null = not snoozed)
     * @param string|null $showAfter The date/time the current recurrence period is over (null = immediate)
     * @param Recurrence $recurrence The recurrence for this request
     * @param array|History[] $history The history of this request
     * @param array|Note[] $notes Notes regarding this request
     * @throws Exception If the ID generation fails
     */
    public function __construct(public string $id = '', public string $enteredOn = '', public string $userId = '',
                                public ?string $snoozedUntil = null, public ?string $showAfter = null,
                                public Recurrence $recurrence = new Recurrence(RecurrencePeriod::Immediate),
                                public array $history = [], public array $notes = [])
    {
        if ($id == '') {
            $this->id = (new Cuid2())->toString();
        }
    }
}
